@@ -12,12 +12,14 @@ def main():
 			args.cards.append(e)
 		if type(e) is Deck:
 			args.decks.append(e)	
-	# accept a file of newline separated cards
+	# accept a file of newline separated card ids
 	if not sys.stdin.isatty():
 		for line in sys.stdin:
-			id = line.strip().split()[0]  # get first entry in line (should be a number)
+			id = line.strip().split()[0]  # first field
 			assert id.isdigit(), f'Bad card id {id}'
 			args.cards.append(Card(id))
+		# reconnect stdin to tty in case we used a pipe
+		sys.stdin = open('/dev/tty')  
 		
 	# run the specified function
 	func = args.func
