@@ -18,6 +18,7 @@ class Deck:
 		self.tags_exclude = tags_exclude
 		self.tags_create = tags_create
 		self.id = id
+		self.deletedQ = False
 	def __str__(self):
 		l = ['+' + t for t in self.tags_include]
 		l += ['-' + t for t in self.tags_exclude]
@@ -83,7 +84,6 @@ class Card:
 		return reviewers.review(self, mode) 
 
 	def default_str(self):
-		# create a str representation for the card
 		return reviewers.default_str(self) 
 
 	def edit(self, mode='e'):
@@ -132,7 +132,7 @@ class Card:
 	def create_date(self):
 		return self.history[0][0]
 	@property
-	def last_date(self):
+	def seen_date(self):
 		return self.history[-1][0]
 	@property
 	def last_grade(self):
@@ -148,10 +148,6 @@ class Card:
 	def deletedQ(self):
 		return self.due_date >= datetime.date(year=3000,month=1,day=1)
 	@property
-	def suspendedQ(self):
-		return self.due_date == 'suspended'
-
-	@property
 	def editor(self):
 		editor, reviewer, scheduler = (self.path/'config').read_text().split()
 		return editor
@@ -203,12 +199,9 @@ class Deckdict(dict):
 			self[i] = deck
 			self.list.append(deck)
 
-	def delete(self, deck):
-		assert deck in self.list, f'{[deck]} not in {self.list}'
-		del self[deck.name]
-		del self[deck.id]
-		self.list.remove(deck)
-		print(*self.list, sep='\n', file=decks_file.open('w'))
+	def save_decks(self):
+		decks_file.write_text('\n'.join([str(deck)
+			for deck in self.list if not deck.deletedQ]))
 
 
 deckdict = Deckdict()
