@@ -25,11 +25,13 @@ def review(card,mode):
 		# front media
 		with DisplayImage(card.path/'image_front'), Recording(card.path/'audio_front'):
 			# card flip
-			if spelltest_words:
-				spelltest(spelltest_words)
-			else:
-				char = readchar.readchar() # press any key to flip the card
-			
+			if mode == 'review':
+				if spelltest_words:
+					spelltest(spelltest_words)
+				else:
+					char = readchar.readchar() # press any key to flip the card
+					if char in ['x','a','q']: # immediate exit actions
+						return char
 		# back text
 		back = '\n' + (card.path / 'back').read_text()
 		print(re.sub(r'\{.*?\}', colorize, back))
@@ -59,7 +61,7 @@ def spelltest(spelltest_words):
 def colorize(match_obj):
 	''' a basic function which uses ansi terminal codes to markup the text
 	whose inputs look like {it, b, yellow, spell: word}
-	It has the side effect of processing spell: attr to spelltest_words.'''
+	It has the side effect of processing spell: attr into spelltest_words.'''
 	# WARNING: functional side effect
 	global spelltest_words
 
